@@ -806,6 +806,51 @@ class SimultanObject(object, metaclass=MetaMock):
         # update the 'slot_components'
         self.slot_components = self.get_slot_components()
 
+    def get_components_with_slot(self, slot: str, slot_extension: list = None, sorted: bool = False):
+        """
+
+        :param slot: Name of the slot
+        :param slot_extension: Slot extension
+        :param sorted: if true, components and referenced are sorted by their slot-extension
+        :return: List with components and references with given slot and slot-extension (optional)
+        """
+        components = []
+        slot_extensions = []
+
+        for comp in self._wrapped_obj.Components.Items:
+            c_slot = comp.Slot.SlotBase.Base
+            c_slot_extension = comp.Slot.SlotExtension
+
+            if c_slot != slot:
+                continue
+            if slot_extension is not None:
+                if c_slot_extension not in slot_extension:
+                    continue
+            components.append(self._template_parser.create_python_object(comp.Component))
+            slot_extensions.append(c_slot_extension)
+
+        for comp in self._wrapped_obj.ReferencedComponents.Items:
+            c_slot = comp.Slot.SlotBase.Base
+            c_slot_extension = comp.Slot.SlotExtension
+
+            if c_slot != slot:
+                continue
+            if slot_extension is not None:
+                if c_slot_extension not in slot_extension:
+                    continue
+            components.append(self._template_parser.create_python_object(comp.Target))
+            slot_extensions.append(c_slot_extension)
+
+        if sorted:
+            try:
+                return [components[i] for i in np.argsort(slot_extensions)]
+            except Exception as e:
+                logger.warning(f'{self.name}: Could not sort components with slot {slot}: {e}')
+                return components
+        else:
+            return components
+
+
 
 class List(UserList):
 
@@ -835,7 +880,7 @@ class List(UserList):
 
         try:
             indices = sort_slots(slots)
-            return [x for _, x in sorted(zip(indices, all_components))]
+            return [all_components[i] for i in np.argsort(indices)]
         except TypeError as e:
             logger.warning(f'Could not sort list {all_components}:\n{e}')
             return all_components
@@ -930,7 +975,7 @@ class ComponentList(UserList):
         components = [x.Component for x in self._wrapped_obj.Components.Items]
         try:
             indices = sort_component_list(self._wrapped_obj.Components.Items)
-            return [x for _, x in sorted(zip(indices, components))]
+            return [components[i] for i in np.argsort(indices)]
         except TypeError as e:
             logger.warning(f'Could not sort list {components}:\n{e}')
             return components
@@ -1034,7 +1079,7 @@ class ReferenceList(UserList):
         ref_components = [x.Target for x in self._wrapped_obj.ReferencedComponents.Items]
         try:
             indices = sort_references(self._wrapped_obj.ReferencedComponents.Items)
-            return [x for _, x in sorted(zip(indices, ref_components))]
+            return [ref_components[i] for i in np.argsort(indices)]
         except TypeError as e:
             logger.warning(f'Could not sort list {ref_components}:\n{e}')
             return ref_components
@@ -1402,11 +1447,12 @@ class BuildInWallConstruction(BaseBuildInConstruction):
 
         # sort the layers by their slot_extension:
         # slot_extensions = [x.slot_extension for x in layers]
-        slot_extensions = [int(x.Slot.SlotExtension) for x in self._wrapped_obj.Components.Items]
+        slot_extensions = [x.Slot.SlotExtension for x in self._wrapped_obj.Components.Items]
         # test with rotated
         # layers = layers[1:] + layers[:1]
 
-        return [x for _, x in sorted(zip(slot_extensions, layers))]
+        return [layers[i] for i in np.argsort(slot_extensions)]
+        # return [x for _, x in sorted(zip(slot_extensions, layers))]
 
 
 class BuildInWindowConstruction(BaseBuildInConstruction):
