@@ -688,7 +688,7 @@ def create_geo_classes(geo_types):
                         volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_1_volume
             else:
                 for p_face in self._wrapped_obj.PFaces:
-                    if p_face.Orientation == 1:
+                    if p_face.Orientation == GeometricOrientation.Forward:
                         volume = self._wrapped_obj.PFaces[0].Volume
 
             if isinstance(volume, Volume):
@@ -711,7 +711,7 @@ def create_geo_classes(geo_types):
                         volume = self.__class__.get_obj_by_id(list(boundary_faces)[0].Id).side_2_volume
             else:
                 for p_face in self._wrapped_obj.PFaces:
-                    if p_face.Orientation == -1:
+                    if p_face.Orientation == GeometricOrientation.Backward:
                         volume = p_face.Volume
             if isinstance(volume, Volume):
                 return GeometricVolume.get_obj_by_id(volume.Id)
